#
# spec file for package systemtap
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
Name:           systemtap
Version:        3.0
Release:        13.12
Summary:        Instrumentation System
License:        GPL-2.0+
Group:          Development/Tools/Debuggers
Url:            http://sourceware.org/systemtap/
Source0:        http://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz
Source1:        README-BEFORE-ADDING-PATCHES
Source2:        stap-server.conf
Patch1:         systemtap-build-source-dir.patch
Patch2:         systemtap-blacklist-powerpc-hash_fault-tracepoint.patch
Patch3:         systemtap-update-runtime-linux-access_process_vm.h.patch
Patch4:         systemtap-get_user_pages-4.9-kernel.patch
Patch5:         systemtap-fix-get_user_pages_remote-test-for-4.10-rc0-kernels.patch
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  libcap-devel
BuildRequires:  libebl-devel
BuildRequires:  mozilla-nspr-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  mozilla-nss-tools
BuildRequires:  pkg-config
BuildRequires:  sqlite-devel
BuildRequires:  systemd
Requires:       %{name}-runtime = %{version}-%{release}
Requires:       libebl1
Obsoletes:      systemtap-client < 1.5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SystemTap is an instrumentation system for systems running Linux.
Developers can write instrumentation to collect data on the operation
of the system.

%package runtime
Summary:        Runtime environment for systemtap
Group:          Development/Tools/Debuggers

%description runtime
SystemTap is an instrumentation system for systems running Linux.
This package contains the runtime environment for systemtap programs.

%package server
Summary:        Systemtap server
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}-%{release}
# dependancies for systemtap shell scripts
Requires:       avahi
Requires:       avahi-utils
Requires:       coreutils
Requires:       mozilla-nss-tools
Requires:       unzip
Requires:       zip
# needed for systemd-tmpfiles
Requires(post): systemd

%description server
SystemTap is an instrumentation system for systems running Linux.
This package contains the server component of systemtap.

%package sdt-devel
Summary:        Static probe support tools
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}-%{release}
Requires:       python-base

%description sdt-devel
SystemTap is an instrumentation system for systems running Linux.
This package contains the support tools for static probes.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
%configure --disable-docs --docdir=%{_docdir}/systemtap
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# XXX
rm -f %{buildroot}%{_libexecdir}/systemtap/stap-server-request
# README, AUTHORS, NEWS, man3 and all examples packaged by systemtap-docs
# COPYING needs to stay in main for GPL
rm -rf %{buildroot}%{_docdir}/systemtap/
rm -rf %{buildroot}%{_mandir}/man3 %{buildroot}%{_mandir}/cs/man3
mkdir -p %{buildroot}%{_docdir}/systemtap/
cp COPYING %{buildroot}%{_docdir}/systemtap/
mkdir -p %{buildroot}%{_localstatedir}/cache/systemtap
mkdir -p %{buildroot}%{_localstatedir}/log
touch %{buildroot}%{_localstatedir}/log/stap-server.log
# config file for stap-server (/var/run now on tmpfs)
mkdir -p %{buildroot}%{_libexecdir}/tmpfiles.d
install -m 644 %{SOURCE2} %{buildroot}%{_libexecdir}/tmpfiles.d

%find_lang systemtap

%post server
# Create tmpfiles
systemd-tmpfiles --create %{_libexecdir}/tmpfiles.d/stap-server.conf

%files
%defattr(-,root,root)
%{_bindir}/stap
%{_mandir}/man[17]/*
%{_mandir}/cs/man[17]/*
%exclude %{_mandir}/man1/dtrace.1*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/runtime
%{_datadir}/%{name}/tapset
#packaged by systemtap-initscript in upstream
%dir %{_localstatedir}/cache/systemtap

%files runtime -f systemtap.lang
%defattr(-,root,root)
%doc %{_docdir}/systemtap
%{_bindir}/staprun
%{_bindir}/stapsh
%{_bindir}/stap-merge
%{_bindir}/stap-report
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/stapio
%{_libexecdir}/%{name}/stap-env
%{_libexecdir}/%{name}/stap-authorize-cert
%{_mandir}/man8/staprun.8*
%{_mandir}/man8/systemtap.8*
%{_mandir}/cs/man8/systemtap.8*
%{_mandir}/man8/stapsh.8*
%{_mandir}/cs/man8/stapsh.8*

%files server
%defattr(-,root,root)
%dir %{_libexecdir}/tmpfiles.d
%{_libexecdir}/tmpfiles.d/stap-server.conf
%{_bindir}/stap-server
%{_libexecdir}/%{name}/stap-gen-cert
%{_libexecdir}/%{name}/stap-serverd
%{_libexecdir}/%{name}/stap-sign-module
%{_libexecdir}/%{name}/stap-start-server
%{_libexecdir}/%{name}/stap-stop-server
%{_mandir}/man8/stap-server.8*
%{_mandir}/cs/man8/stap-server.8*
%ghost %{_localstatedir}/log/stap-server.log
%ghost %dir %{_rundir}/stap-server

%files sdt-devel
%defattr(-,root,root)
%{_bindir}/dtrace
%{_includedir}/sys/*.h
%{_mandir}/man1/dtrace.1*

%changelog
* Fri Apr 28 2017 tonyj@suse.com
- Fix get_user_pages for SP3 kernel (bsc#1031409)
  New patch: systemtap-fix-get_user_pages_remote-test-for-4.10-rc0-kernels.patch
  New patch: systemtap-update-runtime-linux-access_process_vm.h.patch
  New patch: systemtap-get_user_pages-4.9-kernel.patch
* Fri Sep  2 2016 tonyj@suse.com
- Blacklist powerpc:hash_fault tracepoint (bsc#982029)
  New patch: systemtap-blacklist-powerpc-hash_fault-tracepoint.patch
* Thu Apr 14 2016 tonyj@suse.com
- Update SP2 to version 3.0 (due to v4.4 kernel update, bsc#975022)
  Changelog:
    3.0: https://sourceware.org/ml/systemtap/2016-q1/msg00179.html
    2.9: https://sourceware.org/ml/systemtap/2015-q4/msg00025.html
    2.8: https://sourceware.org/ml/systemtap/2015-q2/msg00160.html
    2.7: https://sourceware.org/ml/systemtap/2015-q1/msg00173.html
    2.6: https://sourceware.org/ml/systemtap/2014-q3/msg00231.html
  Cleanups to spec file (based on latest Factory)
  Drop patches (upstream):
  systemtap-fix-dwarfless-probes-on-multiple-static-functions.patch
  systemtap-test-dwarfless-probes-on-multiple-static-functions.patch
  systemtap-prioritize-symbol-table-lookup-for-ppc64le.patch
  systemtap-fix-kernel-relocation-basis-symbol-on-ppc64le.patch
* Mon Apr  4 2016 tonyj@suse.com
- Fix fix kernel relocation basis symbol on ppc64le (bsc#973151)
  New patch: systemtap-fix-kernel-relocation-basis-symbol-on-ppc64le.patch
* Fri Jan  8 2016 tonyj@suse.com
- Fix dtrace manpage (bsc#956823)
* Wed Jul 22 2015 tonyj@suse.com
- Add ppc64le probe support (FATE#319125)
  New patch: systemtap-fix-dwarfless-probes-on-multiple-static-functions.patch
  New patch: systemtap-prioritize-symbol-table-lookup-for-ppc64le.patch
  New patch: systemtap-test-dwarfless-probes-on-multiple-static-functions.patch
* Fri May  2 2014 tonyj@suse.com
- Update to version 2.5
  Changelog:
    2.5: https://sourceware.org/ml/systemtap/2014-q2/msg00103.html
* Fri Nov 15 2013 tonyj@suse.com
- Update to version 2.4
  Changelog:
    2.4: http://sourceware.org/ml/systemtap/2013-q4/msg00165.html
* Wed Aug  7 2013 tonyj@suse.com
- Update to version 2.3
  Changelog:
    2.3: http://sourceware.org/ml/systemtap/2013-q3/msg00062.html
- Refresh systemtap-build-source-dir.patch for context
* Wed May 22 2013 tonyj@suse.com
- Upgrade to version 2.2.1
  Drop patch: systemtap-fix-for-kernels-without-vm_executable.patch
  Refresh patch (context): systemtap-build-source-dir.patch
  Changelog:
    2.1: http://sourceware.org/ml/systemtap/2013-q1/msg00130.html
    2.2.1: http://sourceware.org/ml/systemtap/2013-q2/msg00138.html
* Fri Feb 22 2013 tonyj@suse.com
- Change how systemtap looks for tracepoint header files
  (bnc#796574, new patch: systemtap-build-source-dir.patch)
- Add libebl1 dependancy. Systemtap manually loads libebl backends and
  the manual Requires: was incorrectly removed in a previous revision
  (bnc#800335)
* Fri Dec 14 2012 tonyj@suse.com
- Update to version 2.0
  Changelog: http://sourceware.org/ml/systemtap/2012-q4/msg00047.html
- Delete previous patches (present in version 2.0):
  link-with-pthread.patch
  systemtap-linux-types.patch
- Add patches:
  systemtap-fix-for-kernels-without-vm_executable.patch
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new systemd location.
* Fri Jul 27 2012 aj@suse.de
- Fix build with glibc 2.16
* Mon Jun 18 2012 jslaby@suse.de
- Upgrade to version 1.8
  Changelog: http://sourceware.org/ml/systemtap/2012-q2/msg00277.html
* Sat Feb 18 2012 tonyj@suse.com
- Upgrade to version 1.7
  Changelog: http://sourceware.org/ml/systemtap/2012-q1/msg00097.html
* Wed Nov 23 2011 aj@suse.de
- Create tmpfiles during new install.
* Wed Nov  2 2011 jslaby@suse.de
- update to 1.6
  changes 1.5-1.6: http://sourceware.org/ml/systemtap/2011-q3/msg00105.html
  changes 1.4-1.5: http://sourceware.org/ml/systemtap/2011-q2/msg00218.html
* Fri Aug 19 2011 tonyj@novell.com
- Fix for bnc#710291 - systemtap: fails rpmlint check non-ghost-in-var-run
* Mon May  2 2011 idoenmez@novell.com
- Add systemtap-1.4-gcc46.patch to fix compilation with gcc 4.6
* Tue Mar 15 2011 jslaby@suse.de
- add ifdef CLONE_STOPPED to fix compilation on newer kernels
* Fri Jan 21 2011 tonyj@novell.com
- Update to version 1.4
  Changes in this release: https://lkml.org/lkml/2011/1/17/101
  Drop patches:
  systemtap-hppa.diff
  systemtap-support-2.6.36.diff
  systemtap_fix_mod_vs_del_timer_race.patch
  systemtap_improve_gettimeofday_stability.patch
* Fri Jan 14 2011 trenn@novell.com
- Hopefully fix bnc#664105:
  Kernel segfault in kernel/timer.c - comm: stapio (process) - related to preloadtrace.ko
* Mon Sep 13 2010 coolo@novell.com
- take fix for pr11940 from systemtap git
* Sun Sep  5 2010 bg@novell.com
- fix build for hppa
* Thu Aug 26 2010 tonyj@novell.com
- Update from version 1.1 to version 1.3
  Upstream release notes:
  1.3: http://sourceware.org/ml/systemtap/2010-q3/msg00098.html
  1.2: http://sourceware.org/ml/systemtap/2010-q1/msg00740.html
* Wed Jul 21 2010 vuntz@opensuse.org
- Add python Requires to sdt-devel subpackage since dtrace is a
  python script.
* Thu Mar 11 2010 tonyj@novell.com
- Add dependancies for systemtap shell scripts (coreutils, zip, avahi)
* Thu Mar 11 2010 tonyj@novell.com
- Update to version 1.1
- Fixes for CVE-2009-4273 (second part, also known as CVE-2010-0412) and
  CVE-2010-0411.
- Fix parsing error (systemtap-prevent-nested-arg.diff)
* Wed Dec  2 2009 tonyj@novell.com
- Fixes for CVE-2009-2911, BNC#548361
* Fri Oct  2 2009 tonyj@suse.de
- updated to version 1.0:
  * SystemTap frontend (stap) changes
  - EXPERIMENTAL support for unprivileged users.
  - -a ARCH allows cross compiling of scripts, stap-start-server arguments
    extended to support starting a cross compiling server
  - Change notion of architecture to be same as kernels
  - Support output file switching by SIGUSR2
  - New experimental transport mechanism using ftrace's ring_buffer
  - Reduction in memory consumption for scripts using many uprobes
  - Support for recognizing DW_OP_{stack,implicit}_value DWARF expressions
  * SystemTap script language changes
  - Dwarf probes now support C++ scopes and so can be limited to classes or
    namespaces.
  - Preprocessor support for || and &&
  - Probe alias names may be overloaded (multiple aliases of same name)
  * SystemTap tapset changes
  - Enabling semaphore now used to reduce computation overhead of dorman
    process().mark() probes.
  - Many functions marked as usable by unprivileged users (return global info
    or specific to user process).
  - New netdev tapset probe points for monitoring network traffic and device
    configurations.
  - New task_backtrace function returns the current hex backtrace of any
    arbitrary task in the system.
  - Function is_myproc returns whether the current process is owned by user
    which started systemtap script.
* Thu Aug 13 2009 tiwai@suse.de
- updated to version 0.9.9:
  * Systemwide kernel .function.return (kretprobe) maxactive overridden
  with -DKRETACTIVE=nnn parameter.
  * performance improvement in translation pass 2
  * new DW_OP_call_frame_CFA handling with elfutils 0.142
  * dwarf probes now show parameters and local variables in the verbose
  listing mode (-L)
  * symbol aliases are now resolved to their canonical dwarf names
  * The syntax for dereferencing $target variables and @cast() gained new
  capabilities
  * For reading all probe variables, kernel.mark now supports $$vars and
  $$parms, and process.syscall now supports $$vars.
  * SNMP tapset for many network statistics
  * dentry tapset to map kernel VFS directory entries to file or full
  path names: d_path(), d_name() and reverse_path_walk().
  * SystemTap now has userspace markers in its own binaries
  * More to see in NEWS
* Tue Jul 21 2009 tiwai@suse.de
- corrected to use libexecdir
- fix summary and description
* Tue Jun 16 2009 tiwai@suse.de
- updated to version 0.9.8:
  * Module signing support
  * Debuginfo suggestions when a script fails
  * Using %%M in print formats for hex dumps can now print entire
    buffers
  * Dwarfless syscalls: The nd_syscalls tapset is now available to
    probe system calls without requiring kernel debug info.
  * sid() returns the session ID of the current process
  * stringat() indexes a single character from a string.
  * New script examples
* Wed May 20 2009 tiwai@suse.de
- split docs and examples to docs subpackage and generate from its
  own spec file to cut off the dependency loop
* Fri May 15 2009 tiwai@suse.de
- split to several subpackages, systemtap-runtime, -client, -server
  and -sdt-devel (bnc#503088).
* Fri May  8 2009 tiwai@suse.de
- updated to released version 0.9.7:
  * Lots of fixes, improvements, see NEWS file for details
* Thu Feb 19 2009 tiwai@suse.de
- updated to systemtap snashot 20090214:
  * Version bump to 0.8
  * Bunch of fixes and updates, see ChangeLog
  * Fix for recent 2.6.29 kernels
- fixed doc build, using fop instead of direct xmlto pdf
* Thu Feb 12 2009 tiwai@suse.de
- backport the blacklist additions from upstream to fix possible
  system crash (bnc#459387, bnc#473277)
* Thu Feb  5 2009 tiwai@suse.de
- Backport tapset/signal.stp to fix the signal probe problem
  (bnc#468321)
* Tue Feb  3 2009 tiwai@suse.de
- Fix debugpath.exp with $SYSTEMTAP_DEBUGINFO_PATH (bnc#471811)
* Thu Jan 29 2009 tiwai@suse.de
- Fix procfs dir_entry count warning (bnc#470526)
- Improve the parsing of lineno checks (bnc#468247)
* Thu Jan 15 2009 tiwai@suse.de
- Fix quoting in Tcl scripts (bnc#461588)
* Mon Jan 12 2009 tiwai@suse.de
- Fix syntax errors with Tcl send_log (bnc#460886)
* Thu Dec 18 2008 tiwai@suse.de
- Fix stap failures with signal tapsets (bnc#459387)
* Tue Dec 16 2008 tiwai@suse.de
- Fix dependency on libebl1 (bnc#448331, #445783)
- Fix stap for 2.6.28 kernels
* Fri Dec 12 2008 tiwai@suse.de
- Don't assert of dwarf_getsrcfiles().  This hits recent SUSE
  kernels (bnc#455992)
- Backport fix patches for stap-*-server scripts to run with
  netcat (bnc#446686)
* Mon Dec  8 2008 tiwai@suse.de
- fixed unresolved path in man pages (bnc#457217)
- fixed build for old distros on OBS
* Thu Dec  4 2008 tiwai@suse.de
- fix ioblock.stp for SUSE 2.6.27.x kernel (bnc#456175)
* Fri Nov 21 2008 tiwai@suse.de
- Add the bound check of parameters to fix segfault (bnc#447551)
* Tue Nov  4 2008 tiwai@suse.de
- Fix systemtap assertion with CONFIG_RELOCATABLE (bnc#440351)
* Thu Sep 11 2008 tiwai@suse.de
- updated to snapshot 20080906
  * Fix / clean up autotools stuff
  * Ugly workaround for 2.6.27 and later kernel
  * stap-server updates
  * Lots of small fixes
* Tue Aug 12 2008 tiwai@suse.de
- updated to snapshot 20080809
  * bump to 0.7.1
  * tutorials
  * examples
  * i386-fix merged
  * previous patches are all merged in
- add latex2html to buildrequires for generating documents
* Fri Jun 20 2008 tiwai@suse.de
- fix run on i386 (bnc#401970)
- don't include obsolete linux/compile.h.
* Wed Jun 18 2008 tiwai@suse.de
- updated to snapshot 20080614:
  * bump to version 0.7, man page updates, misc fixes
    see ChangeLog for details
* Fri Mar 14 2008 tiwai@suse.de
- updated to snapshot 20080308:
  * configure fixes, compile option changes
  * fixes for 2.6.25 kernel
* Wed Jan 30 2008 tiwai@suse.de
- updated to snapshot 20080126
  * fix configure and automake stuff
  * gcc 4.3 fix is included
  * ufprobes fixes, improvements
  * reorganized probe condition implementation.
* Fri Jan 11 2008 tiwai@suse.de
- updated to snapshot 20080105
- fixed build of the snapshot with gcc 4.3
* Mon Nov 19 2007 tiwai@suse.de
- enable gcc-4.3 patch (yes, we use only gcc4.3 now)
- updated to snapshot 20071117
* Thu Oct 25 2007 tiwai@suse.de
- disable gcc-4.3 fix again since it breaks older gccs...
* Wed Oct 24 2007 tiwai@suse.de
- fix build with gcc 4.3
* Mon Oct 22 2007 tiwai@suse.de
- updated to snapshot 20071020:
  * bump up version 0.6
  * bunch of updates and fixes, see ChangeLog
* Tue Aug 14 2007 tiwai@suse.de
- updated to snapshot 20070811:
  * Updated -m MODNAME usage
  * Rework on line editing functions
* Mon Jul 16 2007 tiwai@suse.de
- updated to snapshot 20070714:
  * configure fix for sqlite
  * support for crash extension module
  * new enum for type column in coverage_element
* Wed Jul  4 2007 tiwai@suse.de
- updated to snapshot 20070630:
  * auto-tools fixes, sqlite3 requirement
- add sqlite-devel and glib2-devel to buildrequires
* Wed Jun  6 2007 tiwai@suse.de
- updated to snapshot 20070602:
  * fix for gcc4.3
  * minor fixes in elaborate.*
- include the snapshot date into version string
- clean up spec file
* Tue May 22 2007 tiwai@suse.de
- updated to snapshot 20070519:
  * Updated temporary handlings
  * Autoconf tweaks
  * Performance improvements with const and temporary handlings
  * Removed do_write and do_read probles, added aio_write,
    aio_read, writev and readv probes.
* Mon May 21 2007 tiwai@suse.de
- use the external elfutils packages.
* Tue Apr 24 2007 tiwai@suse.de
- updated to snapshot 20070421 and elfutils-0.127:
  * minor compile warning fixes
  * add interruptible parameter
  * improvement on documents
  * fix for debugfs and relayfs mounts
  * see ChangeLog for other changes
* Mon Mar 19 2007 tiwai@suse.de
- updated to snapshot 20070317:
  including all fix patches
* Thu Mar  8 2007 tiwai@suse.de
- fix the handling of function arguments in more generic way
  (#245310, #252311)
  added a new option -P to switch the prologue-search behavior
* Wed Mar  7 2007 tiwai@suse.de
- fix misalignment of exception table entry on s390x (#249576)
* Mon Feb 26 2007 tiwai@suse.de
- fix crash with large H value in hist_linear() (#248430)
* Fri Feb 23 2007 tiwai@suse.de
- fix mmap syscall on s390x (#248110)
* Thu Feb 15 2007 tiwai@suse.de
- fix a wrong name of store_deref definition (#245544)
* Wed Feb 14 2007 tiwai@suse.de
- fix the handling of function arguments on s390x (#245310)
* Tue Feb  6 2007 tiwai@suse.de
- update to snapshot 20070203, bugfixes including:
  * add missing sockets tapset support (#239346)
  * fix the array membership (#242481)
* Wed Jan 31 2007 tiwai@suse.de
- turn on Autoprov again to fix broken dependency.
* Tue Jan 30 2007 tiwai@suse.de
- update to snapshot 20070120 and elfutils-0.125 to fix major
  bugs (#238710):
  * fixed libdw known bugs in elfutils 0.124
  * add the missing support of tapsetr/errno.stp for s390x
  * fix conditionals in syscall tapset for s390x
  * new macros to safely read/write values from kernel pointers
  * fix the non-standard C behavior to handle NULL in an array
  * fixed support for benchmarking mode with off-line code
  * added support to allow user to use array size declarations
  * reduce number of calls to stp_module_relocate within $tvar
    functions
* Tue Jan  9 2007 tiwai@suse.de
- updated to the recent snapshot version (FATE 301670).
  * fix cache bugs
  * auto-tools fixes
  * probe registartion rework
  * allow negative numeric literals
  * bugfixes/optmizations
- elfutls 1.2.4
  removed codes with problematic license in elfutils (#232894)
* Thu Aug 24 2006 tiwai@suse.de
- update elfutils to 1.2.3, including vmlinux.debuginfo fix.
* Thu Aug 24 2006 tiwai@suse.de
- fix the auto-lookup of vmlinux debuginfo for SUSE systems
- fix the stp compilation with 2.6.18 kernel
* Wed Aug  9 2006 tiwai@suse.de
- updated to latest snapshot (version 0.5.8)
  with elfutils-1.2.2.
* Tue Apr 18 2006 mason@suse.de
- Update to latest snapshot
* Sun Apr  9 2006 mason@suse.de
- created package
